@@ -8,7 +8,6 @@
 #'   \item{event}{Description of event}
 #'   \item{event_date}{First date of event}
 #'   \item{end_event_date}{Last date of event}
-#'   ...
 #' }
 #' @source \url{https://en.wikipedia.org/wiki/List_of_Apple_Inc._media_events}
 "apple_events"
@@ -23,7 +22,6 @@
 #'   \item{tag}{Tag}
 #'   \item{number}{Number of questions with tag during year}
 #'   \item{year_total}{Total number of questions with tag during year}
-#'   ...
 #' }
 "by_tag_year"
 
@@ -31,13 +29,12 @@
 #'
 #' A data set containing dates and descriptions for AAERs
 #'
-#' @format A tibble with 40,518 rows and 4 variables:
+#' @format A tibble with 2,920 rows and 4 variables:
 #' \describe{
 #'   \item{aaer_num}{AAER number}
 #'   \item{aaer_date}{Date}
 #'   \item{aaer_desc}{Description}
 #'   \item{year}{Year of AAER}
-#'   ...
 #' }
 "aaer_dates"
 
@@ -61,7 +58,6 @@
 #'   \item{d_sale}{Change in revenue}
 #'   \item{d_ar}{Change in accounts receivable}
 #'   \item{ppe}{Property, plant & equipment (scaled by assets)}
-#'   ...
 #' }
 "comp"
 
@@ -69,7 +65,7 @@
 #'
 #' A simulated data set of test scores.
 #'
-#' @format A tibble with 4000 rows and 5 variables:
+#' @format A tibble with 4,000 rows and 5 variables:
 #' \describe{
 #'   \item{id}{Student identifier}
 #'   \item{grade}{School grade at time of test}
@@ -93,7 +89,7 @@
 #' @source \doi{10.1016/j.jfineco.2018.02.008}
 "idd_dates"
 
-#' Data on firm headquarters based on SEC EDGAR filings.
+#' Data on firm headquarters based on SEC EDGAR filings
 #'
 #' Data on firm headquarters based on SEC EDGAR filings.
 #' Dates related to SEC filing dates. Rather than provide dates for
@@ -108,7 +104,7 @@
 #' any change in state occurs the day after the last observed filing for
 #' the previous state.
 #'
-#' @format A tibble with 24 rows and 3 variables:
+#' @format A tibble with 53,133 rows and 4 variables:
 #' \describe{
 #'   \item{cik}{SEC's Central Index Key (CIK)}
 #'   \item{ba_state}{Two-letter abbreviation of state}
@@ -124,7 +120,7 @@
 #' \describe{
 #'   \item{gvkey}{GVKEY}
 #' }
-#' @source \url{https://research.chicagobooth.edu/-/media/research/arc/docs/journal/online-supplements/llz-datasheet-and-code.zip}
+#' @source \doi{10.1111/1475-679X.12187}
 "llz_2018"
 
 #' Customer names that represent non-disclosures.
@@ -132,14 +128,14 @@
 #' Data to be combined with data in compsegd.seg_customer to create an
 #' indicator for non-disclosure of customer names.
 #'
-#' @format A tibble with 432 rows and 2 variables:
+#' @format A tibble with 460 rows and 2 variables:
 #' \describe{
 #'   \item{cnms}{Matches field in compsegd.seg_customer (WRDS)}
 #'   \item{disclosure}{Indicator that name is not disclosed}
 #' }
 "undisclosed_names"
 
-#' Data on firms suffering natural disasters.
+#' Data on firms suffering natural disasters
 #'
 #' Data on firms suffering natural disasters based on the sample
 #' in Michels (2017).
@@ -159,13 +155,14 @@
 #'   \item{prev_fqtr}{Fiscal quarter of last period-end before event date}
 #'   \item{recognize}{Indicator for event being recognized (next_period_end before date_filed)}
 #' }
+#' @source \doi{10.1111/1475-679X.12128}
 "michels_2017"
 
-#' Data on public float.
+#' Data on public float
 #'
 #' Data on public float of listed companies from Iliev (2010).
 #'
-#' @format A tibble with 7,213 and 9 variables:
+#' @format A tibble with 7,214 and 9 variables:
 #' \describe{
 #'   \item{gvkey}{Compustat firm identifier (GVKEY)}
 #'   \item{fyear}{Fiscal year}
@@ -177,9 +174,10 @@
 #'   \item{af}{Indicator for accelerator filer}
 #'   \item{cik}{SEC firm identifier (CIK)}
 #' }
+#' @source \doi{10.1111/j.1540-6261.2010.01564.x}
 "iliev_2010"
 
-#' Firm-years in RDD analysis of Bloomfield (2021).
+#' Firm-years in RDD analysis of Bloomfield (2021)
 #'
 #' Firm-years in RDD analysis of Bloomfield (2021).
 #'
@@ -188,13 +186,14 @@
 #'   \item{fyear}{Fiscal year}
 #'   \item{permco}{CRSP firm identifier (PERMCO)}
 #' }
+#' @source \doi{10.1111/1475-679X.12346}
 "bloomfield_2021"
 
 #' Treatment indicators for SHO pilot firms
 #'
 #' A data set containing the tickers, GVKEYs, and
 #' treatment indicator for SHO pilot program.
-#'
+#'i
 #' @format A tibble with 3,030 rows × 4 variables.
 #' \describe{
 #'   \item{ticker}{Ticker}
@@ -202,6 +201,7 @@
 #'   \item{permno}{PERMNO (CRSP security identifier)}
 #'   \item{pilot}{SHO pilot program treatment indicator}
 #' }
+#' @source \doi{10.1111/jofi.12369}
 "fhk_pilot"
 
 #' Firm-years for replication of Fang, Huang and Karpoff (2016)
@@ -214,6 +214,7 @@
 #'   \item{gvkey}{GVKEY (firm identifier)}
 #'   \item{datadate}{Fiscal year-end}
 #' }
+#' @source \doi{10.1111/jofi.12369}
 "fhk_firm_years"
 
 #' Tickers of pilot firms for Reg SHO.
@@ -227,7 +228,7 @@
 #'   \item{ticker}{Ticker}
 #'   \item{co_name}{Company name}
 #' }
-#' @source \url{https://www.sec.gov/rules/other/34-50104.htm}
+#' @source \url{https://www.sec.gov/rule-release/34-50104}
 "sho_tickers"
 
 #' Russell 3000 stocks at time of SEC Reg SHO sample formation.
@@ -241,6 +242,7 @@
 #'   \item{russell_ticker}{Ticker}
 #'   \item{russell_name}{Company name}
 #' }
+#' @source \doi{10.1111/jofi.12369}
 "sho_r3000"
 
 #' Russell 3000 sample used by SEC
@@ -254,7 +256,7 @@
 #'   \item{permno}{PERMNO (CRSP security identifier)}
 #'   \item{pilot}{Indicator for stock being part of Reg SHO pilot program}
 #' }
-#' @source \url{http://iangow.me/far_book/natural-revisited.html#the-sho-pilot-sample}
+#' @source \url{https://iangow.github.io/far_book/natural-revisited.html#the-sho-pilot-sample}
 "sho_r3000_sample"
 
 #' Russell 3000 sample used by SEC with GVKEYs
@@ -269,7 +271,7 @@
 #'   \item{gvkey}{GVKEY (Compustat firm identifier)}
 #'   \item{pilot}{Indicator for stock being part of Reg SHO pilot program}
 #' }
-#' @source \url{http://iangow.me/far_book/natural-revisited.html#the-sho-pilot-sample}
+#' @source \url{https://iangow.github.io/far_book/natural-revisited.html#the-sho-pilot-sample}
 "sho_r3000_gvkeys"
 
 #' Event windows from Zhang (2007)
@@ -314,6 +316,7 @@
 #'   \item{min_year}{First affected year}
 #'   \item{max_year}{Last affected year}
 #'}
+#' @source \doi{10.1111/1475-679X.12292}
 "aaer_firm_year"
 
 #' Australian banks
@@ -355,3 +358,58 @@
 #'   \item{mkt_cap}{Market capitalization on datadate}
 #'}
 "aus_bank_rets"
+
+#' Data for CMSW
+#'
+#' Data on whistleblowers and enforcement actions from Call et al. (2018)
+#'
+#' @format A tibble with 1,133 rows and 31 variables:
+#' \describe{
+#'   \item{recid}{CMSW record identifier}
+#'   \item{firmpenalty}{The total firm civil and criminal monetary penalties assessed against the firm, its parent and subsidiaries consisting of disgorgement, prejudgment interest, civil fines, criminal restitution, and criminal fines in millions of dollars}
+#'   \item{otherpenalty}{The total firm civil and criminal monetary penalties assessed against the agent firms and/or respondents (e.g., the audit firm, bankers, suppliers) in connection with the financial misrepresentation of the target firm, in millions of dollars}
+#'   \item{emppenalty}{The total civil and criminal penalties assessed against all employees consisting of disgorgement, prejudgment interest, civil fines, criminal restitution, and criminal fines in millions of dollars}
+#'   \item{empprisonmos}{Total incarceration consisting of jail, prison, home detention, and halfway house in months imposed upon employee respondents named in the enforcement action}
+#'   \item{selfdealflag}{An indicator variable equal to one if the violation includes self-dealing such as embezzlement and theft by respondents and equal to zero otherwise}
+#'   \item{blckownpct}{The percentage of blockholder ownership, defined as owners with at least five percent of common shares outstanding from the last 10-K or DEF 14A prior to the first public announcement the firm may be (is) subject to a regulatory enforcement action}
+#'   \item{initabret}{The value-weighted market-adjusted return measured at the close of trading on the initial public announcement date that the firm may be (is) subject to a regulatory enforcement action}
+#'   \item{wbflag}{An indicator variable equal to one if a whistleblower is associated with the enforcement action and equal to zero otherwise}
+#'   \item{tousesox}{Post-SOX action flag}
+#'   \item{lnvioperiod}{The natural logarithm of the total time the violation occurred in months as indicated in the regulatory enforcement proceedings}
+#'   \item{bribeflag}{An indicator variable equal to one if the enforcement actions includes charges under the Foreign Corrupt Practices Act for bribery of a foreign official and zero otherwise}
+#'   \item{mobflag}{An indicator variable equal to one if violation or any of the respondents were associated with a known organized crime family and zero otherwise}
+#'   \item{deter}{An indicator variable equal to one if the violation includes an offense for either option backdating, insider trading, or an offense related to an offering, IPO, merger, or reverse merger and equal to zero otherwise}
+#'   \item{lnempcleveln}{The natural logarithm of the total number of C-level respondents (e.g. CEO, COO, CFO, CAO, CMO, and CIO) named in the enforcement action}
+#'   \item{lnuscodecnt}{The natural logarithm of the total number of unique code sections and rules violated (charges) associated with the enforcement action}
+#'   \item{viofraudflag}{n indicator variable equal to one if fraud under 15 USC §§ 77q, 78j(b), or rules promulgated thereunder are included among the charges in the enforcement action}
+#'   \item{misledflag}{An indicator variable equal to one if the violation included violations of 17 CFR 240.13b2-2 that prohibits materially false or misleading statement to an accountant in connection with the preparation of financial statements and zero otherwise}
+#'   \item{audit8flag}{An indicator variable equal to one if the misreporting firm used a Big N auditor, and equal to zero otherwise}
+#'   \item{exectermflag}{An indicator variable equal to one if the firm terminated an executive respondent as a result of the violations and equal to zero otherwise}
+#'   \item{coopflag}{An indicator variable equal to one if the firm received credit in the assessment of penalties for cooperation as stated in regulatory enforcement documents during the course of the investigation and equal to zero otherwise}
+#'   \item{impedeflag}{An indicator variable equal to one if regulators acknowledged they were deliberately misled and/or charges were included for lying to investigators and equal to zero otherwise}
+#'   \item{pctinddir}{The percentage of the firm's directors that are independent from the last 10-K or DEF 14A prior to the first public announcement the firm may be (is) subject to a regulatory enforcement action}
+#'   \item{recidivist}{An indicator variable equal to one if the firm was previously the subject of a securities regulatory enforcement action and equal to zero otherwise}
+#'   \item{lnmktcap}{The natural logarithm of the market value of equity measured in millions of dollars prior to the first public announcement that the firm may be (is) subject to a regulatory enforcement action}
+#'   \item{mkt2bk}{The sum of market value of equity plus total assets minus total debt divided by total assets with market value determined below and total assets and total debt measured at the last fiscal year end prior to the first public announcement the firm may be (is) subject to a regulatory enforcement action}
+#'   \item{lev}{Total debt divided by total assets measured at the last fiscal year end prior to the first public announcement the firm may be (is) subject to a regulatory enforcement action}
+#'   \item{lndistance}{The natural logarithm of the distance in miles from the location of the firm's headquarters to the offices of the regulator assigned to the geographic area of the firm's headquarter location (closer of the SEC Regional Office or DOJ U.S. District Attorney).}
+#'   \item{ff12}{Fama-French industry code (12-industry)}
+#'   \item{wbsource}{Whistleblower data source}
+#'   \item{wbtype}{Whistleblower type: tipster or nontipster}
+#' }
+#' @source \doi{10.1111/1475-679X.12177}
+"cmsw_2018"
+
+#' GVKEY-CIK links
+#'
+#' Link table from GVKEYs to CIKs
+#'
+#' @format A tibble with 76,346 rows and 5 variables:
+#' \describe{
+#'   \item{gvkey}{GVKEY (Compustat firm identifier)}
+#'   \item{iid}{Issue ID}
+#'   \item{cik}{CIK (SEC firm identifier)}
+#'   \item{first_date}{First link date}
+#'   \item{last_date}{Last link date}
+#' }
+"gvkey_ciks"
